@@ -53,9 +53,9 @@ def base(timeout=10):
     while time.monotonic() - start_timer < timeout:
         while not nrf.fifo(False, True):  # keep RX FIFO empty for reception
             # show the pipe number that received the payload
-            # NOTE recv() clears the pipe number and payload length data
+            # NOTE read() clears the pipe number and payload length data
             print("Received", nrf.any(), "on pipe", nrf.pipe, end=" ")
-            node_id, payload_id = struct.unpack("<ii", nrf.recv())
+            node_id, payload_id = struct.unpack("<ii", nrf.read())
             print("from node {}. PayloadID: {}".format(node_id, payload_id))
             start_timer = time.monotonic()  # reset timer with every payload
     nrf.listen = False
@@ -79,15 +79,15 @@ def node(node_number=0, count=6):
         # payloads will include the node_number and a payload ID character
         payload = struct.pack("<ii", node_number, counter)
         # show something to see it isn't frozen
-        start_timer = time.monotonic() * 1000
+        start_timer = time.monotonic_ns()
         report = nrf.send(payload)
-        end_timer = time.monotonic() * 1000
+        end_timer = time.monotonic_ns()
         # show something to see it isn't frozen
         if report:
             print(
                 "Transmission of payloadID {} as node {} successfull! "
-                "Transmission time: {} ms".format(
-                    counter, node_number, end_timer - start_timer
+                "Transmission time: {} us".format(
+                    counter, node_number, (end_timer - start_timer) / 1000
                 )
             )
         else:
